# Connectomes

## Connectome protocol

Connectomes must implement the `Connectome` protocol to be compatible
with `flyvis.network.network.Network`.

::: flyvis.connectome.connectome.Connectome

## Compilation from average filters

::: flyvis.connectome.connectome.ConnectomeFromAvgFilters

## Analysis and visualization

::: flyvis.connectome.connectome.ConnectomeView

::: flyvis.connectome.connectome.ReceptiveFields

::: flyvis.connectome.connectome.ProjectiveFields

## Miscellaneous

::: flyvis.connectome.connectome.init_connectome

::: flyvis.connectome.connectome.get_avgfilt_connectome
